.. _ng-estimator:

NgEstimator
===========
.. inheritance-diagram:: gmmvi.optimization.gmmvi_modules.ng_estimator.NgEstimator gmmvi.optimization.gmmvi_modules.ng_estimator.SteinNgEstimator gmmvi.optimization.gmmvi_modules.ng_estimator.MoreNgEstimator
    :parts: -4

.. autoclass:: gmmvi.optimization.gmmvi_modules.ng_estimator.NgEstimator
   :members:
   :undoc-members:

.. _more:

MoreNgEstimator
~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.ng_estimator.MoreNgEstimator
   :members:
   :undoc-members:

.. _stein:

SteinNgEstimator
~~~~~~~~~~~~~~~~
.. autoclass:: gmmvi.optimization.gmmvi_modules.ng_estimator.SteinNgEstimator
   :members:
   :undoc-members:

.. toctree::
   :maxdepth: 2
   :glob: